#ifndef NT2_INCLUDE_FUNCTIONS_IS_GTZ_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_GTZ_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_gtz.hpp>

#endif
